@@ -8,7 +8,9 @@ use Mojo::SQLite::Results;
 use Mojo::SQLite::Transaction;
 use Scalar::Util 'weaken';
 
-our $VERSION = '0.011';
+our $VERSION = '0.012';
+
+our @CARP_NOT = qw(Mojo::SQLite::Migrations);
 
 has [qw(dbh sqlite)];
 
@@ -62,7 +64,8 @@ sub query {
   }
 
   if ($errored) {
-    die $error unless $cb;
+    # Croak error for better context
+    croak $error unless $cb;
     $error = $self->dbh->errstr;
   }
 
