@@ -7,7 +7,7 @@ use Mojo::Util qw(decode slurp);
 
 use constant DEBUG => $ENV{MOJO_MIGRATIONS_DEBUG} || 0;
 
-our $VERSION = '0.011';
+our $VERSION = '0.012';
 
 has name => 'migrations';
 has 'sqlite';
@@ -70,7 +70,17 @@ sub migrate {
 
   warn "-- Migrate ($active -> $target)\n$query\n" if DEBUG;
   local $db->dbh->{sqlite_allow_multiple_statements} = 1;
-  $db->dbh->do($query);
+
+  # Catch the error so we can croak it  
+  my ($errored, $error, $result);
+  {
+    local $@;
+    eval { $result = $db->dbh->do($query); 1 } or $errored = 1;
+    $error = $@ if $errored;
+  }
+  croak $error if $errored;
+  return $self unless defined $result; # RaiseError disabled
+  
   $db->query('update mojo_migrations set version = ? where name = ?',
     $target, $self->name) and $tx->commit;
 
